DeepSeekCodeModelConnector class

Constructors

DeepSeekCodeModelConnector({required String apiKey, required DeepSeekModel model})

Properties

apiKey → String
final
hashCode → int
The hash code for this object.
no setterinherited
model → DeepSeekModel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendCode(String code, {Map<String, dynamic>? extraOptions}) → Future<String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited