AIConnectorError class

Custom error class for AI connector errors.

Implemented types

Constructors

AIConnectorError(String message, [Exception? innerException])

Properties

hashCode → int
The hash code for this object.
no setterinherited
innerException → Exception?
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited