Models enum

Inheritance
Available extensions

Values

GEMINI → const Models
const Models('Gemini')
GPT_3 → const Models
const Models('GPT-3')
GPT_4 → const Models
const Models('GPT-4')
LLAMA_2 → const Models
const Models('LLaMA-2')
CLAUDE → const Models
const Models('Claude')
CLAUDE_V1 → const Models
const Models('Claude-v1')
CLAUDE_V2 → const Models
const Models('Claude-v2')
CLAUDE_V3 → const Models
const Models('Claude-v3')
PALM → const Models
const Models('PaLM')
OPENAI → const Models
const Models('OpenAI')
META → const Models
const Models('Meta')
DEEPSEEK → const Models
const Models('DeepSeek')
GROK → const Models
const Models('Grok')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<Models>
A constant List of the values in this enum, in order of their declaration.