GenConnectManager class

Properties

anthropic → AnthropicConnector?
no setter
availableModels → List<String>
no setter
cloude → ClaudeConnector?
no setter
deepseek → DeepSeekConnector?
no setter
gemini → GeminiConnector?
no setter
grok → GrokConnector?
no setter
hashCode → int
The hash code for this object.
no setterinherited
meta → MetaConnector?
no setter
openai → OpenAIConnector?
no setter
palm → PalmConnector?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addConnector(AIModelConnector connector) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

dio → Dio
no setter

Static Methods

getInstance() → GenConnectManager